.. pymgclient documentation master file, created by
   sphinx-quickstart on Thu May 16 09:51:30 2019.
   You can adapt this file completely to your liking, but it should at least
   contain the root `toctree` directive.

========================================================
pymgclient -- DB-API 2.0 interface for Memgraph database
========================================================

pymgclient is a `Memgraph <https://memgraph.com/>`_ database adapter for Python
language compliant with the DB-API 2.0 specification described by :pep:`249`.


.. toctree::
   :maxdepth: 2
   :caption: Contents:

   introduction
   usage
   module
   connection
   cursor

Indices and tables
==================

* :ref:`genindex`
* :ref:`search`
